@@ -7,7 +7,8 @@
 // the GNU Public License (>= 2.0). A copy of this license can be obtained at
 // <http://www.gnu.org/licenses/gpl-2.0.html>.
 
-const double PI = 3.141592653589793238463 ;
+
+//const double PI = 3.141592653589793238463 ;
 
 #include <Rcpp.h>
 
@@ -16,6 +17,8 @@ double enttn1(const double mean,
               const double low,
               const double high
               ) {
+
+
     // Normalize bounds
     double alpha = (low - mean) / sd ;
     double beta = (high - mean) / sd ;
